# Discord Verification Bot

A simple, dockerized Discord bot that manages the verification of new members. New joiners can type `!verifyme` in the designated verification channel, and the bot will send a request to moderators to manually grant them access. The bot also creates the verification channel on startup but **does not create roles or set permissions** for the verification channel to allow moderators access.

## Features
- Automatically sets up a verification channel when the bot starts.
- Listens for the `!verifyme` command from new members in the verification channel.
- Notifies moderators when a new member requests verification.
- Minimal configuration required to start and deploy using Docker.

## Getting Started

### Prerequisites
- Docker and Docker Compose installed on your machine.
- A Discord bot token. [Create one here](https://discord.com/developers/applications).

### 1. Clone the Repository

```bash
git clone <repository_url>
cd discord-verification-bot
```

### 2. Configure the Bot Token

1. Open `docker-compose.yml` in a text editor.
2. Replace `YOUR_BOT_TOKEN_HERE` with the token for your Discord bot.

**Example:**
```yaml
services:
  bot:
    build: .
    environment:
      - DISCORD_TOKEN=INSERTTOKENHERE
    restart: always
```

### 3. Build and Run the Bot Using Docker

Build the Docker image:
```bash
docker-compose build
```

Start the bot:
```bash
docker-compose up
```

The bot will start and create a verification channel (e.g., #verification) if it doesn’t already exist.

### 4. Add the Bot to Your Server

1. Go to the [Discord Developer Portal](https://discord.com/developers/applications).
2. Select your bot application and navigate to **Bot**.
3. Under **Privileged Gateway Intents**, select:
   - `Server Members Intent`
   - `Message Content Intent`
4. Navigate to **OAuth2 > URL Generator**.
5. Under **OAuth2 Scopes**, select `bot`.
6. Under **OAuth2 Bot Permissions**, select:
   - `Add Reactions`
   - `Send Messages`
   - `Manage Channels` (so it can create the verification channel)
   - `Manage Roles` (so it can add the member role)
7. Copy the generated URL and paste it into your browser to add the bot to your server.

**Note:** You must have the **Manage Server** permission to add bots to a server.

## Usage

Once the bot is running and added to your server:

1. When a new member joins, they can go to the verification channel (e.g., #verification).
2. Type `!verifyme` in the channel.
3. The bot will notify moderators that a new member has requested verification. Moderators will need to manually assign the appropriate role to grant access.

### Permissions Note
This bot only creates the verification channel and listens for the `!verifyme` command. Moderators will need to:
- Set permissions on the verification channel to allow moderators to view messages.
- Create a **moderator role** and **member role** if they are not already present.

## Environment Variables

The bot uses the following environment variables, which you should define in `docker-compose.yml` or in your own environment if running outside Docker.

| Variable         | Description                       |
|------------------|-----------------------------------|
| `DISCORD_TOKEN`  | Your Discord bot token. Required |

## Contributing
Feel free to submit a pull request or create an issue for any feature requests or bug fixes!

## License
This project is licensed under the MIT License.

---

If you have any questions, feel free to reach out! Enjoy using the Discord Verification Bot!